@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -63,9 +62,9 @@ module SiSU_Markup
   class Source
     def initialize(opt)
       @opt=opt
-      @env=SiSU_Env::Info_env.new(@opt.fns)
+      @env=SiSU_Env::InfoEnv.new(@opt.fns)
       md=SiSU_Param::Parameters.new(@opt).get
-      @file=SiSU_Env::SiSU_file.new(md)
+      @file=SiSU_Env::FileOp.new(md)
       stub=@opt.fnb.gsub(/~[a-z]+$/,'')
     end
     def read
@@ -77,16 +76,21 @@ module SiSU_Markup
       end
       FileUtils::mkdir_p(@file.output_path.src.dir) unless FileTest.directory?(@file.output_path.src.dir)
       if FileTest.directory?(@file.output_path.src.dir)
-        unless @opt.fns =~/\.ssm$/; FileUtils::cp(@opt.fns,@file.output_path.src.dir)
+        unless @opt.fns =~/\.ssm$/
+          if FileTest.file?(@opt.fns)
+            FileUtils::cp(@opt.fns,@file.output_path.src.dir)
+          else STDERR.puts %{\t*WARN* did not find - "#{@opt.fns}"}
+          end
         else
           req=@opt.fns.gsub(/(.+?\.ssm)$/,'\1.sst')
           file="#{@env.processing_path.composite_file}/#{@opt.fnb}.ssm.sst"
-          if FileTest.file?(file); FileUtils::cp(file,"#{@file.output_path.src.dir}/#{req}")
-          else print "did not find #{file} to copy"
+          if FileTest.file?(file)
+            FileUtils::cp(file,"#{@file.output_path.src.dir}/#{req}")
+          else STDERR.puts "*WARN* did not find #{file} to copy"
           end
         end
       else
-        SiSU_Screen::Ansi.new(@opt.cmd,"Output directory does not exist","#{@opt.fns} -> #{@file.output_path.src.dir}").warn if @opt.cmd =~/[MVv]/
+        SiSU_Screen::Ansi.new(@opt.cmd,"*WARN* Output directory does not exist","#{@opt.fns} -> #{@file.output_path.src.dir}").warn if @opt.cmd =~/[MVv]/
         exit
       end
     end
