@@ -7,7 +7,8 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008, 2009, 2010, 2011, 2012 Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -33,9 +34,7 @@
    <http://www.fsf.org/licensing/licenses/gpl.html>
    <http://www.gnu.org/licenses/gpl.html>
 
-   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
+   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -47,7 +46,7 @@
    <http://www.sisudoc.org>
 
  * Download:
-   <http://www.jus.uio.no/sisu/SiSU/download.html>
+   <http://www.sisudoc.org/sisu/en/SiSU/download.html>
 
  * Ralph Amissah
    <ralph@amissah.com>
@@ -479,67 +478,6 @@ module SiSU_TeX_Pdf
         @txt.gsub!(/#{Mx[:lnk_o]}\S+\.(png|jpg|gif).+?#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,'') # fragile match operator\\ fragile !
       end
     end
-    def image
-      dir=SiSU_Env::InfoEnv.new(@md.fns)
-      image,m=/#{Mx[:lnk_o]}\s*(\S+)\s+.+?width=``(\d+)''.+?#{Mx[:lnk_c]}/m.match(@txt).captures
-      width=m[1] || '100'
-      width=width.to_i*0.4
-      image_source=if @md.fns =~/\.(?:ssm\.)?sst$/ \
-      and FileTest.file?("#{dir.path.image_source_include_local}/#{image}")
-        dir.path.image_source_include_local
-      elsif @md.fns =~/\.-ss[tm]$/ \
-      and FileTest.file?("#{dir.path.image_source_include_remote}/#{image}")
-        dir.path.image_source_include_remote
-      elsif FileTest.file?("#{dir.path.image_source_include}/#{image}")
-        dir.path.image_source_include
-      else
-        SiSU_Screen::Ansi.new(@md.opt.cmd,"ERROR - image:",%{"#{image}" missing},"search locations: #{dir.path.image_source_include_local},#{dir.path.image_source_include_remote} and #{dir.path.image_source_include}").error2 unless @md.opt.cmd =~/q/
-        nil
-      end
-      if image_source #CHECK
-        @txt.gsub!(/#{Mx[:lnk_o]}\s*(\S+)\s+.+?#{Mx[:lnk_c]}/,
-          @center_begin + "\\includegraphics*[width=#{width}pt]{#{image_source}/\\1}" + @center_end )
-      else @txt.gsub!(/#{Mx[:lnk_o]}\s*(\S+)\s+.+?#{Mx[:lnk_c]}/,'\1}')
-      end
-    end
-    def png(ps='') #fc missing image check
-      dir=SiSU_Env::InfoEnv.new(@md.fns)
-      # messy clean up
-      z=@txt[/#{Mx[:lnk_o]}(\S.+?)#{Mx[:lnk_c]}(?:image|png)/,1].strip if @txt =~ /#{Mx[:lnk_o]}\S.+?#{Mx[:lnk_c]}(?:image|png)/ # match operator for z \\ fragile !
-      if z #debug 2004w14
-        image=z[/(\S+?\.(?:png|jpg|gif)\b)/m]
-        image.gsub!(/\\/,'')
-        width=if z =~ /\d+x\d*/
-          w=(z[/\s(\d+)x\d*/,1]).to_i
-          w*0.8
-        else '100' #revisit, is bug for small images/icons
-        end
-        width='380' if width.to_i > 380
-        c=z[/``(.+?)''/m]
-      end
-      hsp="\n{\\color{mywhite} .}&~\n" # ~ character for hardspace
-      caption="{\\\\\\\ \n\\begin{scriptsize}#{hsp*3}#{c}\\end{scriptsize}&}" if c
-      image_source=if @md.fns =~/\.(?:ssm\.)?sst$/ \
-      and FileTest.file?("#{dir.path.image_source_include_local}/#{image}")
-        dir.path.image_source_include_local
-      elsif @md.fns =~/\.-ss[tm]$/ \
-      and FileTest.file?("#{dir.path.image_source_include_remote}/#{image}")
-        dir.path.image_source_include_remote
-      elsif FileTest.file?("#{dir.path.image_source_include}/#{image}")
-        dir.path.image_source_include
-      else
-        unless image.nil? \
-        or image.length < 2
-          SiSU_Screen::Ansi.new(@md.opt.cmd,"ERROR - image:",%{"#{image}" missing},"search locations: #{dir.path.image_source_include_local},#{dir.path.image_source_include_remote} and #{dir.path.image_source_include}").error2 unless @md.opt.cmd =~/q/
-        end
-        nil
-      end
-      if image_source
-        @txt.gsub!(/#{Mx[:lnk_o]}\S+\.(png|jpg|gif).+?#{Mx[:lnk_c]}(image|png)/, # fragile match operator\\ fragile !
-          "#{@center_begin}\n\\includegraphics*[width=#{width}pt]{#{image_source}/#{image}}#{caption}#{@center_end}")
-      else @txt.gsub!(/#{Mx[:lnk_o]}\S+\.(png|jpg|gif).+?#{Mx[:lnk_c]}(image|png)/,'')
-      end
-    end
     def url_str_internal(str,idx=nil)
       map_nametags=SiSU_Particulars::CombinedSingleton.instance.get_map_nametags(@md).nametags_map #p map_nametags
       rgx_url_generic=/#{Mx[:lnk_o]}.+?#{Mx[:lnk_c]}#{Mx[:rel_o]}\S+?#{Mx[:rel_c]}/m
@@ -685,7 +623,34 @@ module SiSU_TeX_Pdf
               images_hash[ps].gsub!(/#{Mx[:lnk_o]}\s*(\S+\.?\.(?:png|jpg|gif))/,'[image]')
             end
             if image #most images fc etc. #% clean up !
-              if @md.fns =~/\.(?:ssm\.)?sst$/ \
+              if FileTest.file?("#{dir.path.image_source_include}/#{image}")
+                case images_hash[ps]
+                when url_image_rgx
+                  images_hash[ps].sub!(url_image_rgx,
+                    "#{@center_begin}\\\n\\href{#{url}}\n{\\includegraphics*[width=#{width[ps]}pt]{#{dir.path.image_source_include}/#{image}}}#{caption}#{@center_end}")
+                when image_rgx
+                  images_hash[ps].sub!(image_rgx,
+                    "#{@center_begin}\\\n\\includegraphics*[width=#{width[ps]}pt]{#{dir.path.image_source_include}/#{image}}#{caption}#{@center_end}")
+                end
+                images_hash[ps]
+              elsif @md.opt.f_pth[:pth] =~/\/\S+?\/sisupod\/\S+?\/sisupod\/doc/
+                pt=/(\/\S+?\/sisupod\/\S+?\/sisupod)\/doc/.match(@md.opt.f_pth[:pth])[1]
+                img_src=pt + '/image'
+                if FileTest.file?("#{img_src}/#{image}")
+                  img_src
+
+                  case images_hash[ps]
+                  when url_image_rgx
+                    images_hash[ps].sub!(url_image_rgx,
+                      "#{@center_begin}\\\n\\href{#{url}}{\\includegraphics*[width=#{width[ps]}pt]{#{img_src}/#{image}}}#{caption} #{@center_end}")
+                  when image_rgx
+                    images_hash[ps].sub!(image_rgx,
+                      "#{@center_begin}\\\n\\includegraphics*[width=#{width[ps]}pt]{#{img_src}/#{image}}#{caption} #{@center_end}")
+                  end
+                  images_hash[ps]
+                end
+
+              elsif @md.fns =~/\.(?:ssm\.)?sst$/ \
               and FileTest.file?("#{dir.path.image_source_include_local}/#{image}")
                 case images_hash[ps]
                 when url_image_rgx
@@ -707,16 +672,6 @@ module SiSU_TeX_Pdf
                     "#{@center_begin}\\\n\\includegraphics*[width=#{width[ps]}pt]{#{dir.path.image_source_include_remote}/#{image}}#{caption}#{@center_end}")
                 end
                 images_hash[ps]
-              elsif FileTest.file?("#{dir.path.image_source_include}/#{image}")
-                case images_hash[ps]
-                when url_image_rgx
-                  images_hash[ps].sub!(url_image_rgx,
-                    "#{@center_begin}\\\n\\href{#{url}}\n{\\includegraphics*[width=#{width[ps]}pt]{#{dir.path.image_source_include}/#{image}}}#{caption}#{@center_end}")
-                when image_rgx
-                  images_hash[ps].sub!(image_rgx,
-                    "#{@center_begin}\\\n\\includegraphics*[width=#{width[ps]}pt]{#{dir.path.image_source_include}/#{image}}#{caption}#{@center_end}")
-                end
-                images_hash[ps]
               else
                 SiSU_Screen::Ansi.new(@md.opt.cmd,"ERROR - image:",%{"#{image}" missing},"search locations: #{dir.path.image_source_include_local},#{dir.path.image_source_include_remote} and #{dir.path.image_source_include}").error2 unless @md.opt.cmd =~/q/
                 if images_hash[ps] =~url_image_rgx \
