@@ -284,8 +284,8 @@ module SiSU_Urls
       unless @opt.cmd =~/q/
         i="(output manifest) [#{@opt.f_pth[:lng_is]}] #{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}"
         @opt.cmd=~/[MVvz]/ \
-        ? SiSU_Screen::Ansi.new(@opt.cmd,'URLs').grey_title_hi
-        : SiSU_Screen::Ansi.new(@opt.cmd,'URL',i).green_hi_blue
+        ? SiSU_Screen::Ansi.new(@opt.cmd,'URLs').green_title_hi
+        : SiSU_Screen::Ansi.new(@opt.cmd,'URL',i).grey_title_hi
         SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@md.file.output_path.manifest.dir}/#{@md.file.base_filename.manifest}").flow if @opt.cmd =~/[MVv]/
       end
       m=/.+\/(?:src\/)?(\S+)/im # m=/.+?\/(?:src\/)?([^\/]+)$/im # m=/.+\/(\S+)/m
